@@ -131,10 +131,12 @@ class _SubtypeAssigner(pytree_visitor.PyTreeVisitor):
     # comp_op ::= '<'|'>'|'=='|'>='|'<='|'<>'|'!='|'in'|'not in'|'is'|'is not'
     for child in node.children:
       self.Visit(child)
-      if (isinstance(child, pytree.Leaf) and child.value in {
-          '<', '>', '==', '>=', '<=', '<>', '!=', 'in', 'not in', 'is', 'is not'
-      }):
+      if (isinstance(child, pytree.Leaf) and
+          child.value in {'<', '>', '==', '>=', '<=', '<>', '!=', 'in', 'is'}):
         _AppendTokenSubtype(child, format_token.Subtype.BINARY_OPERATOR)
+      elif pytree_utils.NodeName(child) == 'comp_op':
+        for grandchild in child.children:
+          _AppendTokenSubtype(grandchild, format_token.Subtype.BINARY_OPERATOR)
 
   def Visit_star_expr(self, node):  # pylint: disable=invalid-name
     # star_expr ::= '*' expr
@@ -344,6 +346,18 @@ def _InsertPseudoParentheses(node):
   first = _GetFirstLeafNode(node)
   last = _GetLastLeafNode(node)
 
+  if first == last and first.type == token.COMMENT:
+    # A comment was inserted before the value, which is a pytree.Leaf.
+    # Encompass the dictionary's value into an ATOM node.
+    last = first.next_sibling
+    new_node = pytree.Node(syms.atom, [first.clone(), last.clone()])
+    node.replace(new_node)
+    node = new_node
+    last.remove()
+
+    first = _GetFirstLeafNode(node)
+    last = _GetLastLeafNode(node)
+
   lparen = pytree.Leaf(
       token.LPAR, u'(', context=('', (first.get_lineno(), first.column - 1)))
   last_lineno = last.get_lineno()
