@@ -138,7 +138,7 @@ class MainTest(unittest.TestCase):
       ret = yapf.main(['-', '--style-help', '--style=pep8'])
       self.assertEqual(ret, 0)
       help_message = out.getvalue()
-      self.assertIn("INDENT_WIDTH=4", help_message)
+      self.assertIn("indent_width=4", help_message)
       self.assertIn("The number of spaces required before a trailing comment.",
                     help_message)
 
